<?php

namespace Litecms\Institute\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Institute\Interfaces\InstituteRepositoryInterface;

class InstitutePublicController extends BaseController
{
    // use InstituteWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Institute\Interfaces\InstituteRepositoryInterface $institute
     *
     * @return type
     */
    public function __construct(InstituteRepositoryInterface $institute)
    {
        $this->repository = $institute;
        parent::__construct();
    }

    /**
     * Show institute's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $institutes = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$institute::$institute.names'))
            ->view('$institute::public.institute.index')
            ->data(compact('$institutes'))
            ->output();
    }

    /**
     * Show institute's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $institutes = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$institute::$institute.names'))
            ->view('$institute::public.institute.index')
            ->data(compact('$institutes'))
            ->output();
    }

    /**
     * Show institute.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $institute = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$institute->name . trans('$institute::$institute.name'))
            ->view('$institute::public.institute.show')
            ->data(compact('$institute'))
            ->output();
    }

}
