<?php

namespace Litecms\Institute\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Institute\Models\InstituteCourse;

class InstituteCoursePolicy
{

    /**
     * Determine if the given user can view the institute_course.
     *
     * @param UserPolicy $user
     * @param InstituteCourse $institute_course
     *
     * @return bool
     */
    public function view(UserPolicy $user, InstituteCourse $institute_course)
    {
        if ($user->canDo('institute.institute_course.view') && $user->isAdmin()) {
            return true;
        }

        return $institute_course->user_id == user_id() && $institute_course->user_type == user_type();
    }

    /**
     * Determine if the given user can create a institute_course.
     *
     * @param UserPolicy $user
     * @param InstituteCourse $institute_course
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('institute.institute_course.create');
    }

    /**
     * Determine if the given user can update the given institute_course.
     *
     * @param UserPolicy $user
     * @param InstituteCourse $institute_course
     *
     * @return bool
     */
    public function update(UserPolicy $user, InstituteCourse $institute_course)
    {
        if ($user->canDo('institute.institute_course.edit') && $user->isAdmin()) {
            return true;
        }

        return $institute_course->user_id == user_id() && $institute_course->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given institute_course.
     *
     * @param UserPolicy $user
     * @param InstituteCourse $institute_course
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, InstituteCourse $institute_course)
    {
        return $institute_course->user_id == user_id() && $institute_course->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given institute_course.
     *
     * @param UserPolicy $user
     * @param InstituteCourse $institute_course
     *
     * @return bool
     */
    public function verify(UserPolicy $user, InstituteCourse $institute_course)
    {
        if ($user->canDo('institute.institute_course.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given institute_course.
     *
     * @param UserPolicy $user
     * @param InstituteCourse $institute_course
     *
     * @return bool
     */
    public function approve(UserPolicy $user, InstituteCourse $institute_course)
    {
        if ($user->canDo('institute.institute_course.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
