<?php

namespace Litecms\Institute\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Institute\Models\Institute;

class InstitutePolicy
{

    /**
     * Determine if the given user can view the institute.
     *
     * @param UserPolicy $user
     * @param Institute $institute
     *
     * @return bool
     */
    public function view(UserPolicy $user, Institute $institute)
    {
        if ($user->canDo('institute.institute.view') && $user->isAdmin()) {
            return true;
        }

        return $institute->user_id == user_id() && $institute->user_type == user_type();
    }

    /**
     * Determine if the given user can create a institute.
     *
     * @param UserPolicy $user
     * @param Institute $institute
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('institute.institute.create');
    }

    /**
     * Determine if the given user can update the given institute.
     *
     * @param UserPolicy $user
     * @param Institute $institute
     *
     * @return bool
     */
    public function update(UserPolicy $user, Institute $institute)
    {
        if ($user->canDo('institute.institute.edit') && $user->isAdmin()) {
            return true;
        }

        return $institute->user_id == user_id() && $institute->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given institute.
     *
     * @param UserPolicy $user
     * @param Institute $institute
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Institute $institute)
    {
        return $institute->user_id == user_id() && $institute->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given institute.
     *
     * @param UserPolicy $user
     * @param Institute $institute
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Institute $institute)
    {
        if ($user->canDo('institute.institute.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given institute.
     *
     * @param UserPolicy $user
     * @param Institute $institute
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Institute $institute)
    {
        if ($user->canDo('institute.institute.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
