<?php

namespace Litecms\Institute\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litecms\Institute\Models\Institute;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\Institute\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/institute/institute/*')) {
            Route::bind('institute', function ($institute) {
                $instituterepo = $this->app->make('Litecms\Institute\Interfaces\InstituteRepositoryInterface');
                return $instituterepo->findorNew($institute);
            });
        }

        if (Request::is('*/institute/course/*')) {
            Route::bind('course', function ($course) {
                $courserepo = $this->app->make('Litecms\Institute\Interfaces\CourseRepositoryInterface');
                return $courserepo->findorNew($course);
            });
        }

        if (Request::is('*/institute/institute_course/*')) {
            Route::bind('institute_course', function ($institute_course) {
                $institute_courserepo = $this->app->make('Litecms\Institute\Interfaces\InstituteCourseRepositoryInterface');
                return $institute_courserepo->findorNew($institute_course);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
